Crate signet_zenith

Crate signet_zenith 

signet-zenith

Rust types & utilities for working with Zenith smart contracts.

What’s in this crate?

  • alloy Bindings for Zenith smart contracts
    • Zenith
    • Passage
    • Orders
  • AggregateOrders - a struct that holds the net Order data for a transaction or set of transactions.
  • SignedOrder - a struct that holds a signed Order and the signature that was used to sign it. This enables users to make gasless orders using the permit2 orders iunterface.
  • ZenithBlock - a struct used to decode transaction data from Ethereum blobs containing builder-created blocks.

Modules

BundleHelper
Contract Bindings for the BundleHelper contract.
HostOrders
Contract Bindings for the HostOrders contract.
Passage
Contract Bindings for the Passage contract.
RollupOrders
Contract Bindings for the RollupOrders contract.
RollupPassage
Contract Bindings for the RollupPassage contract.
Transactor
Generated by the following Solidity interface…
Zenith
Generated by the following Solidity interface…

Structs

Alloy2718Coder
Coder for encode_txns and decode_txns that operates on TxEnvelope.
ZenithBlock
A Zenith block is just a list of transactions.
mintCall
Function with signature mint(address,uint256) and selector 0x40c10f19.

Constants

MINTER_ADDRESS
System address with permission to mint tokens on pre-deploys. “tokenadmin”

Traits

Coder
Encode/Decode trait for inner tx type

Functions

decode_txns
Decode transactions.
encode_txns
Encode a set of transactions into a single RLP-encoded buffer.

Type Aliases

ZenithTransaction
Zenith processes normal Ethereum txns.