signet-zenith
Rust types & utilities for working with Zenith smart contracts.
What’s in this crate?
- alloy Bindings for Zenith smart contracts
ZenithPassageOrders
AggregateOrders- a struct that holds the netOrderdata for a transaction or set of transactions.SignedOrder- a struct that holds a signedOrderand the signature that was used to sign it. This enables users to make gasless orders using the permit2 orders iunterface.ZenithBlock- a struct used to decode transaction data from Ethereum blobs containing builder-created blocks.
Modules
- Bundle
Helper - Contract Bindings for the BundleHelper contract.
- Host
Orders - Contract Bindings for the HostOrders contract.
- Passage
- Contract Bindings for the Passage contract.
- Rollup
Orders - Contract Bindings for the RollupOrders contract.
- Rollup
Passage - Contract Bindings for the RollupPassage contract.
- Transactor
- Generated by the following Solidity interface…
- Zenith
- Generated by the following Solidity interface…
Structs
- Alloy2718
Coder - Coder for
encode_txnsanddecode_txnsthat operates onTxEnvelope. - Zenith
Block - A Zenith block is just a list of transactions.
- mint
Call - Function with signature
mint(address,uint256)and selector0x40c10f19.
Constants
- MINTER_
ADDRESS - System address with permission to mint tokens on pre-deploys. “tokenadmin”
Traits
- Coder
- Encode/Decode trait for inner tx type
Functions
- decode_
txns - Decode transactions.
- encode_
txns - Encode a set of transactions into a single RLP-encoded buffer.
Type Aliases
- Zenith
Transaction - Zenith processes normal Ethereum txns.